import sys
from pathlib import Path, PosixPath
import configparser

from de.p1st.exec_notify.lib import util


def getHostAndPort():
    try:
        return config['mail']['host'], config['mail']['port']
    except Exception as e:
        print(f'execNotify>> Could not read value [mail][host] from {_getCfgFile()}', file=sys.stderr)
        exit(1)


def getPassword():
    try:
        return config['mail']['password']
    except Exception as e:
        print(f'execNotify>> Could not read value [mail][password] from {_getCfgFile()}', file=sys.stderr)
        exit(1)


def getFrom():
    try:
        return config['mail']['from']  # used for mail login as well
    except Exception as e:
        print(f'execNotify>> Could not read value [mail][from] from {_getCfgFile()}', file=sys.stderr)
        exit(1)


def getTo():
    try:
        return config['mail']['to']
    except Exception as e:
        print(f'execNotify>> Could not read value [mail][to] from {_getCfgFile()}', file=sys.stderr)
        exit(1)


def getMailDir() -> Path:
    try:
        return Path(config['file']['maildir'])
    except Exception as e:
        print(f'execNotify>> Could not read value [file][maildir] from {_getCfgFile()}', file=sys.stderr)
        exit(1)


def _getCfgFile() -> Path:
    return _getCfgDir().joinpath('cfg.ini')


def _getCfgDir() -> Path:
    if util.isInDevelopment():
        return util.getProjectBase().joinpath('etc','execNotify')
    else:
        return PosixPath('/etc/execNotify/')


config: configparser.ConfigParser = configparser.ConfigParser()
config.read(_getCfgFile())
